==> openshift-model-machine-5.12.3-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.MachineFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.Machine,io.fabric8.openshift.api.model.machine.v1beta1.MachineBuilder>{
  public MachineBuilder() {
    this(false);
  }
  public MachineBuilder(java.lang.Boolean validationEnabled) {
    this(new Machine(), validationEnabled);
  }
  public MachineBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Machine(), validationEnabled);
  }
  public MachineBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.Machine instance) {
    this(fluent, instance, false);
  }
  public MachineBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.Machine instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineBuilder(io.fabric8.openshift.api.model.machine.v1beta1.Machine instance) {
    this(instance,false);
  }
  public MachineBuilder(io.fabric8.openshift.api.model.machine.v1beta1.Machine instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.MachineFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.Machine build() {
    Machine buildable = new Machine(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineBuilder that = (MachineBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.5.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineBuilder extends MachineFluentImpl<MachineBuilder> implements VisitableBuilder<Machine,MachineBuilder>{
  public MachineBuilder() {
    this(false);
  }
  public MachineBuilder(Boolean validationEnabled) {
    this(new Machine(), validationEnabled);
  }
  public MachineBuilder(MachineFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineBuilder(MachineFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Machine(), validationEnabled);
  }
  public MachineBuilder(MachineFluent<?> fluent,Machine instance) {
    this(fluent, instance, false);
  }
  public MachineBuilder(MachineFluent<?> fluent,Machine instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineBuilder(Machine instance) {
    this(instance,false);
  }
  public MachineBuilder(Machine instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineFluent<?> fluent;
  Boolean validationEnabled;
  public Machine build() {
    Machine buildable = new Machine(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
